@@ -8,6 +8,9 @@ from peek_abstract_chunked_index.private.tuples.ACIUpdateDateTupleABC import (
     ACIUpdateDateTupleABC,
 )
 from peek_core_search._private.PluginNames import searchFilt
+from peek_core_search._private.client.controller.SearchIndexCacheController import (
+    clientSearchIndexUpdateFromServerFilt,
+)
 from peek_core_search._private.tuples.search_index.SearchIndexUpdateDateTuple import (
     SearchIndexUpdateDateTuple,
 )
@@ -23,5 +26,6 @@ clientSearchIndexWatchUpdateFromDeviceFilt.update(searchFilt)
 # ModelSet HANDLER
 class SearchIndexCacheHandler(ACICacheHandlerABC):
     _UpdateDateTuple: ACIUpdateDateTupleABC = SearchIndexUpdateDateTuple
-    _updateFromServerFilt: Dict = clientSearchIndexWatchUpdateFromDeviceFilt
+    _updateFromDeviceFilt: Dict = clientSearchIndexWatchUpdateFromDeviceFilt
+    _updateFromLogicFilt: Dict = clientSearchIndexUpdateFromServerFilt
     _logger: logging.Logger = logger
